import sinon from 'sinon';
import { service as bankSlipService } from './bankSlip.js';
import { BankSlipInterface } from './bankSlipInterface.js';

const urlParams = {
  affiliationCode: '321321321',
};

describe('Bank Slip Module', () => {
  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = bankSlipService(postRequest);

    service.post(urlParams, BankSlipInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = bankSlipService(postRequest);

    service.post(urlParams, BankSlipInterface);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/bankslip');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = bankSlipService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
